==> apache-camel-4.4.1-src.zip: apache-camel-4.4.1/core/camel-core/src/test/java/org/apache/camel/processor/SetRouteVariableTransferTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

public class SetRouteVariableTransferTest extends ContextTestSupport {
    private MockEndpoint end;
    private String variableName = "foo";
    private String expectedVariableValue = "bar";

    @Test
    public void testSetExchangeVariableMidRoute() throws Exception {
        end.expectedBodiesReceived(expectedVariableValue);

        template.sendBody("direct:start", "Hello World");

        assertMockEndpointsSatisfied();
    }

    @Override
    @BeforeEach
    public void setUp() throws Exception {
        super.setUp();
        end = getMockEndpoint("mock:end");
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            public void configure() {
                // stored as route variable
                from("direct:start").routeId("myRoute")
                        // sets variable in another route
                        .setVariable("route:myRoute2:" + variableName).constant(expectedVariableValue)
                        .to("direct:bar")
                        .to("mock:end");

                from("direct:bar").routeId("myRoute2")
                        .setBody().variable("route:" + variableName);
            }
        };
    }
}

==> apache-camel-4.10.7-src.zip: apache-camel-4.10.7/core/camel-core/src/test/java/org/apache/camel/processor/SetRouteVariableTransferTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

public class SetRouteVariableTransferTest extends ContextTestSupport {
    private MockEndpoint end;
    private final String variableName = "foo";
    private final String expectedVariableValue = "bar";

    @Test
    public void testSetExchangeVariableMidRoute() throws Exception {
        end.expectedBodiesReceived(expectedVariableValue);

        template.sendBody("direct:start", "Hello World");

        assertMockEndpointsSatisfied();
    }

    @Override
    @BeforeEach
    public void setUp() throws Exception {
        super.setUp();
        end = getMockEndpoint("mock:end");
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            public void configure() {
                // stored as route variable
                from("direct:start").routeId("myRoute")
                        // sets variable in another route
                        .setVariable("route:myRoute2:" + variableName).constant(expectedVariableValue)
                        .to("direct:bar")
                        .to("mock:end");

                from("direct:bar").routeId("myRoute2")
                        .setBody().variable("route:" + variableName);
            }
        };
    }
}
